==> mingw-w64-clang-aarch64-petsc-build-3.21.5-1-any.pkg.tar.zst: clangarm64/src/petsc/dto/include/petscconf_poison.h <==
#pragma GCC poison PETSC_PETSC_HAVE_ACCESS
#pragma GCC poison PETSC_PETSC_HAVE_ATOLL
#pragma GCC poison PETSC_PETSC_HAVE_ATTRIBUTEALIGNED
#pragma GCC poison PETSC_PETSC_HAVE_BUILTIN_EXPECT
#pragma GCC poison PETSC_PETSC_HAVE_C99_COMPLEX
#pragma GCC poison PETSC_PETSC_HAVE_CLOCK
#pragma GCC poison PETSC_PETSC_HAVE_DIRECT_H
#pragma GCC poison PETSC_PETSC_HAVE_DOS_H
#pragma GCC poison PETSC_PETSC_HAVE_DOUBLE_ALIGN_MALLOC
#pragma GCC poison PETSC_PETSC_HAVE_ERF
#pragma GCC poison PETSC_PETSC_HAVE_FCNTL_H
#pragma GCC poison PETSC_PETSC_HAVE_FENV_H
#pragma GCC poison PETSC_PETSC_HAVE_FE_VALUES
#pragma GCC poison PETSC_PETSC_HAVE_FLOAT_H
#pragma GCC poison PETSC_PETSC_HAVE_FREELIBRARY
#pragma GCC poison PETSC_PETSC_HAVE_GETCOMPUTERNAME
#pragma GCC poison PETSC_PETSC_HAVE_GETCWD
#pragma GCC poison PETSC_PETSC_HAVE_GETLASTERROR
#pragma GCC poison PETSC_PETSC_HAVE_GETPROCADDRESS
#pragma GCC poison PETSC_PETSC_HAVE_GET_USER_NAME
#pragma GCC poison PETSC_PETSC_HAVE_HWLOC
#pragma GCC poison PETSC_PETSC_HAVE_IEEEFP_H
#pragma GCC poison PETSC_PETSC_HAVE_INTTYPES_H
#pragma GCC poison PETSC_PETSC_HAVE_IO_H
#pragma GCC poison PETSC_PETSC_HAVE_ISINF
#pragma GCC poison PETSC_PETSC_HAVE_ISNAN
#pragma GCC poison PETSC_PETSC_HAVE_ISNORMAL
#pragma GCC poison PETSC_PETSC_HAVE_LARGE_INTEGER_U
#pragma GCC poison PETSC_PETSC_HAVE_LGAMMA
#pragma GCC poison PETSC_PETSC_HAVE_LOADLIBRARY
#pragma GCC poison PETSC_PETSC_HAVE_LOG2
#pragma GCC poison PETSC_PETSC_HAVE_LSEEK
#pragma GCC poison PETSC_PETSC_HAVE_MALLOC_H
#pragma GCC poison PETSC_PETSC_HAVE_MEMMOVE
#pragma GCC poison PETSC_PETSC_HAVE_MKSTEMP
#pragma GCC poison PETSC_PETSC_HAVE_MPIUNI
#pragma GCC poison PETSC_PETSC_HAVE_MPI_REDUCE_LOCAL
#pragma GCC poison PETSC_PETSC_HAVE_OPENBLAS
#pragma GCC poison PETSC_PETSC_HAVE_OPENBLAS_SET_NUM_THREADS
#pragma GCC poison PETSC_PETSC_HAVE_OPENMP
#pragma GCC poison PETSC_PETSC_HAVE_O_BINARY
#pragma GCC poison PETSC_PETSC_HAVE_PACKAGES
#pragma GCC poison PETSC_PETSC_HAVE_POPEN
#pragma GCC poison PETSC_PETSC_HAVE_RAND
#pragma GCC poison PETSC_PETSC_HAVE_REAL___FP16
#pragma GCC poison PETSC_PETSC_HAVE_REGEX
#pragma GCC poison PETSC_PETSC_HAVE_SETJMP_H
#pragma GCC poison PETSC_PETSC_HAVE_SETLASTERROR
#pragma GCC poison PETSC_PETSC_HAVE_SLEEP
#pragma GCC poison PETSC_PETSC_HAVE_SNPRINTF
#pragma GCC poison PETSC_PETSC_HAVE_STDATOMIC_H
#pragma GCC poison PETSC_PETSC_HAVE_STDINT_H
#pragma GCC poison PETSC_PETSC_HAVE_STRCASECMP
#pragma GCC poison PETSC_PETSC_HAVE_STRICMP
#pragma GCC poison PETSC_PETSC_HAVE_STRINGS_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_PARAM_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_TIME_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_TYPES_H
#pragma GCC poison PETSC_PETSC_HAVE_TAU_PERFSTUBS
#pragma GCC poison PETSC_PETSC_HAVE_TGAMMA
#pragma GCC poison PETSC_PETSC_HAVE_TIME
#pragma GCC poison PETSC_PETSC_HAVE_TIME_H
#pragma GCC poison PETSC_PETSC_HAVE_TMPNAM_S
#pragma GCC poison PETSC_PETSC_HAVE_UNISTD_H
#pragma GCC poison PETSC_PETSC_HAVE_USLEEP
#pragma GCC poison PETSC_PETSC_HAVE_VA_COPY
#pragma GCC poison PETSC_PETSC_HAVE_VSNPRINTF
#pragma GCC poison PETSC_PETSC_HAVE_WINDOWSX_H
#pragma GCC poison PETSC_PETSC_HAVE_WINDOWS_H
#pragma GCC poison PETSC_PETSC_HAVE_WS2TCPIP_H
#pragma GCC poison PETSC_PETSC_HAVE__ACCESS
#pragma GCC poison PETSC_PETSC_HAVE__GETCWD
#pragma GCC poison PETSC_PETSC_HAVE__LSEEK
#pragma GCC poison PETSC_PETSC_HAVE__MKDIR
#pragma GCC poison PETSC_PETSC_HAVE__SLEEP
#pragma GCC poison PETSC_PETSC_HAVE__SNPRINTF
#pragma GCC poison PETSC_PETSC_HAVE___INT64
#pragma GCC poison PETSC_PETSC_USE_AVX512_KERNELS
#pragma GCC poison PETSC_PETSC_USE_BACKWARD_LOOP
#pragma GCC poison PETSC_PETSC_USE_CTABLE
#pragma GCC poison PETSC_PETSC_USE_DMLANDAU_2D
#pragma GCC poison PETSC_PETSC_USE_INFO
#pragma GCC poison PETSC_PETSC_USE_ISATTY
#pragma GCC poison PETSC_PETSC_USE_LOG
#pragma GCC poison PETSC_PETSC_USE_MALLOC_COALESCED
#pragma GCC poison PETSC_PETSC_USE_MICROSOFT_TIME
#pragma GCC poison PETSC_PETSC_USE_PROC_FOR_SIZE
#pragma GCC poison PETSC_PETSC_USE_REAL_DOUBLE
#pragma GCC poison PETSC_PETSC_USE_SINGLE_LIBRARY

==> mingw-w64-clang-aarch64-petsc-build-3.23.3-1-any.pkg.tar.zst: clangarm64/src/petsc/dto/include/petscconf_poison.h <==
#pragma GCC poison PETSC_PETSC_HAVE_ACCESS
#pragma GCC poison PETSC_PETSC_HAVE_ATOLL
#pragma GCC poison PETSC_PETSC_HAVE_ATTRIBUTEALIGNED
#pragma GCC poison PETSC_PETSC_HAVE_BUILTIN_EXPECT
#pragma GCC poison PETSC_PETSC_HAVE_C99_COMPLEX
#pragma GCC poison PETSC_PETSC_HAVE_CLOCK
#pragma GCC poison PETSC_PETSC_HAVE_DIRECT_H
#pragma GCC poison PETSC_PETSC_HAVE_DOS_H
#pragma GCC poison PETSC_PETSC_HAVE_DOUBLE_ALIGN_MALLOC
#pragma GCC poison PETSC_PETSC_HAVE_ERF
#pragma GCC poison PETSC_PETSC_HAVE_FCNTL_H
#pragma GCC poison PETSC_PETSC_HAVE_FENV_H
#pragma GCC poison PETSC_PETSC_HAVE_FE_VALUES
#pragma GCC poison PETSC_PETSC_HAVE_FLOAT_H
#pragma GCC poison PETSC_PETSC_HAVE_FREELIBRARY
#pragma GCC poison PETSC_PETSC_HAVE_GETCOMPUTERNAME
#pragma GCC poison PETSC_PETSC_HAVE_GETCWD
#pragma GCC poison PETSC_PETSC_HAVE_GETLASTERROR
#pragma GCC poison PETSC_PETSC_HAVE_GETPROCADDRESS
#pragma GCC poison PETSC_PETSC_HAVE_GET_USER_NAME
#pragma GCC poison PETSC_PETSC_HAVE_HWLOC
#pragma GCC poison PETSC_PETSC_HAVE_IEEEFP_H
#pragma GCC poison PETSC_PETSC_HAVE_INTTYPES_H
#pragma GCC poison PETSC_PETSC_HAVE_IO_H
#pragma GCC poison PETSC_PETSC_HAVE_ISINF
#pragma GCC poison PETSC_PETSC_HAVE_ISNAN
#pragma GCC poison PETSC_PETSC_HAVE_ISNORMAL
#pragma GCC poison PETSC_PETSC_HAVE_LARGE_INTEGER_U
#pragma GCC poison PETSC_PETSC_HAVE_LGAMMA
#pragma GCC poison PETSC_PETSC_HAVE_LOADLIBRARY
#pragma GCC poison PETSC_PETSC_HAVE_LOG2
#pragma GCC poison PETSC_PETSC_HAVE_LSEEK
#pragma GCC poison PETSC_PETSC_HAVE_MALLOC_H
#pragma GCC poison PETSC_PETSC_HAVE_MEMMOVE
#pragma GCC poison PETSC_PETSC_HAVE_MKSTEMP
#pragma GCC poison PETSC_PETSC_HAVE_MPIUNI
#pragma GCC poison PETSC_PETSC_HAVE_MPI_COUNT
#pragma GCC poison PETSC_PETSC_HAVE_MPI_LARGE_COUNT
#pragma GCC poison PETSC_PETSC_HAVE_MPI_REDUCE_LOCAL
#pragma GCC poison PETSC_PETSC_HAVE_OPENBLAS
#pragma GCC poison PETSC_PETSC_HAVE_OPENBLAS_SET_NUM_THREADS
#pragma GCC poison PETSC_PETSC_HAVE_OPENMP
#pragma GCC poison PETSC_PETSC_HAVE_O_BINARY
#pragma GCC poison PETSC_PETSC_HAVE_PACKAGES
#pragma GCC poison PETSC_PETSC_HAVE_POPEN
#pragma GCC poison PETSC_PETSC_HAVE_RAND
#pragma GCC poison PETSC_PETSC_HAVE_REAL___FP16
#pragma GCC poison PETSC_PETSC_HAVE_SETJMP_H
#pragma GCC poison PETSC_PETSC_HAVE_SETLASTERROR
#pragma GCC poison PETSC_PETSC_HAVE_SLEEP
#pragma GCC poison PETSC_PETSC_HAVE_SNPRINTF
#pragma GCC poison PETSC_PETSC_HAVE_STDATOMIC_H
#pragma GCC poison PETSC_PETSC_HAVE_STDINT_H
#pragma GCC poison PETSC_PETSC_HAVE_STRCASECMP
#pragma GCC poison PETSC_PETSC_HAVE_STRICMP
#pragma GCC poison PETSC_PETSC_HAVE_STRINGS_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_PARAM_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_TIME_H
#pragma GCC poison PETSC_PETSC_HAVE_SYS_TYPES_H
#pragma GCC poison PETSC_PETSC_HAVE_TAU_PERFSTUBS
#pragma GCC poison PETSC_PETSC_HAVE_TGAMMA
#pragma GCC poison PETSC_PETSC_HAVE_TIME
#pragma GCC poison PETSC_PETSC_HAVE_TIME_H
#pragma GCC poison PETSC_PETSC_HAVE_TMPNAM_S
#pragma GCC poison PETSC_PETSC_HAVE_UNISTD_H
#pragma GCC poison PETSC_PETSC_HAVE_USLEEP
#pragma GCC poison PETSC_PETSC_HAVE_VA_COPY
#pragma GCC poison PETSC_PETSC_HAVE_VSNPRINTF
#pragma GCC poison PETSC_PETSC_HAVE_WINDOWSX_H
#pragma GCC poison PETSC_PETSC_HAVE_WINDOWS_H
#pragma GCC poison PETSC_PETSC_HAVE_WS2TCPIP_H
#pragma GCC poison PETSC_PETSC_HAVE__ACCESS
#pragma GCC poison PETSC_PETSC_HAVE__GETCWD
#pragma GCC poison PETSC_PETSC_HAVE__LSEEK
#pragma GCC poison PETSC_PETSC_HAVE__MKDIR
#pragma GCC poison PETSC_PETSC_HAVE__SLEEP
#pragma GCC poison PETSC_PETSC_HAVE__SNPRINTF
#pragma GCC poison PETSC_PETSC_HAVE___INT64
#pragma GCC poison PETSC_PETSC_USE_AVX512_KERNELS
#pragma GCC poison PETSC_PETSC_USE_BACKWARD_LOOP
#pragma GCC poison PETSC_PETSC_USE_CTABLE
#pragma GCC poison PETSC_PETSC_USE_DMLANDAU_2D
#pragma GCC poison PETSC_PETSC_USE_INFO
#pragma GCC poison PETSC_PETSC_USE_ISATTY
#pragma GCC poison PETSC_PETSC_USE_LOG
#pragma GCC poison PETSC_PETSC_USE_MALLOC_COALESCED
#pragma GCC poison PETSC_PETSC_USE_MICROSOFT_TIME
#pragma GCC poison PETSC_PETSC_USE_PROC_FOR_SIZE
#pragma GCC poison PETSC_PETSC_USE_REAL_DOUBLE
#pragma GCC poison PETSC_PETSC_USE_SINGLE_LIBRARY
